%define anolis_release 1
# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/evince/
%global __requires_exclude ^(%%(find %{buildroot}%{_libdir}/evince/ -name '*.so' | xargs -n1 basename | sort -u | paste -s -d '|' -))

%global libarchive_version 3.6.0
%global poppler_version 22.02.0

Name:           evince
Version:        44.1
Release:        %{anolis_release}%{?dist}
Summary:        Document viewer

License:        GPLv2+ and GPLv3+ and LGPLv2+ and MIT and Afmparse
URL:            https://wiki.gnome.org/Apps/Evince
Source0:        https://download.gnome.org/sources/%{name}/44/%{name}-%{version}.tar.xz

BuildRequires:  gcc
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(adwaita-icon-theme)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(libarchive) >= %{libarchive_version}
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(poppler-glib) >= %{poppler_version}
BuildRequires:  libtiff-devel
BuildRequires:  gi-docgen
BuildRequires:  yelp-tools
BuildRequires:  libappstream-glib-devel
BuildRequires:  meson
BuildRequires:  systemd-rpm-macros
BuildRequires:  djvulibre-devel
# for the xps backend
BuildRequires:  pkgconfig(libgxps)
# for the dvi backend
BuildRequires:  pkgconfig(kpathsea)
BuildRequires:  pkgconfig(synctex)

Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-previewer = %{version}-%{release}
Requires: %{name}-thumbnailer = %{version}-%{release}

Obsoletes: %{name}-nautilus < 43~alpha-2

%description
Evince is simple multi-page document viewer. It can display and print
Portable Document Format (PDF), PostScript (PS) and Encapsulated PostScript
(EPS) files. When supported by the document format, evince allows searching
for text, copying text to the clipboard, hypertext navigation,
table-of-contents bookmarks and editing of forms.

 Support for other document formats such as DVI and DJVU can be added by
installing additional backends.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.


%package libs
Summary: Libraries for the evince document viewer
Recommends: %{name}-djvu = %{version}-%{release}
Requires:   libarchive >= %{installed_version_of libarchive}
Requires:   poppler-glib >= %{installed_version_of poppler-glib}

%description libs
This package contains shared libraries needed for evince


%package devel
Summary: Support for developing backends for the evince document viewer
Requires: %{name}-libs = %{version}-%{release}
# Because web fonts from upstream are not bundled in the gi-docgen package,
# packages containing documentation generated with gi-docgen should depend on
# this metapackage to ensure the proper system fonts are present.
Recommends: gi-docgen-fonts

%description devel
This package contains libraries and header files needed for evince
backend development.


%package dvi
Summary: Evince backend for dvi files
Requires: %{name}-libs = %{version}-%{release}
Requires: texlive-collection-fontsrecommended

%description dvi
This package contains a backend to let evince display dvi files.


%package djvu
Summary: Evince backend for djvu files
Requires: %{name}-libs = %{version}-%{release}

%description djvu
This package contains a backend to let evince display djvu files.

%package thumbnailer
Summary: Evince thumbnailer
Requires: %{name}-libs = %{version}-%{release}

%description thumbnailer
This package brings the Evince thumbnailer independently from Evince.

%package previewer
Summary: Evince previewer
Requires: %{name}-libs = %{version}-%{release}

%description previewer
This package brings the Evince previewer independently from Evince.
It provides the printing preview for the GTK printing dialog.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%meson \
        -Dcomics=enabled \
        -Ddvi=enabled \
        -Ddjvu=enabled \
        -Dxps=enabled \
        -Dnautilus=false \
        -Dps=enabled
%meson_build

%install
%meson_install

%find_lang evince --with-gnome

mkdir -p %{buildroot}%{_datadir}/applications
rm -f %{buildroot}%{_metainfodir}/evince-pdfdocument.metainfo.xml
rm -f %{buildroot}%{_metainfodir}/evince-psdocument.metainfo.xml
rm -f %{buildroot}%{_metainfodir}/evince-tiffdocument.metainfo.xml
rm -f %{buildroot}%{_metainfodir}/evince-comicsdocument.metainfo.xml
rm -f %{buildroot}%{_metainfodir}/evince-xpsdocument.metainfo.xml

%generate_compatibility_deps

%check
appstream-util validate-relax --nonet $RPM_BUILD_ROOT%{_datadir}/metainfo/org.gnome.Evince.appdata.xml

%files -f evince.lang
%{_bindir}/evince
%{abidir}/evince-option.list
%{_datadir}/applications/org.gnome.Evince.desktop
%{_datadir}/evince/
%{_datadir}/icons/hicolor/*/apps/org.gnome.Evince.*
%{_datadir}/icons/hicolor/*/apps/org.gnome.Evince-symbolic.svg
%{_mandir}/man1/evince.1*
%{_libexecdir}/evinced
%{_datadir}/dbus-1/services/org.gnome.evince.Daemon.service
%{_datadir}/glib-2.0/schemas/org.gnome.Evince.gschema.xml
%{_datadir}/GConf/gsettings/evince.convert
%{_metainfodir}/org.gnome.Evince.appdata.xml
%{_userunitdir}/org.gnome.Evince.service

%files doc
%doc NEWS AUTHORS

%files libs
%license COPYING
%dir %{abidir}
%{_libdir}/libevdocument3.so.4*
%{_libdir}/libevview3.so.3*
%{abidir}/libevdocument3.dump
%{abidir}/libevview3.dump
%dir %{_libdir}/evince
%dir %{_libdir}/evince/4
%dir %{_libdir}/evince/4/backends
%{_libdir}/evince/4/backends/libpdfdocument.so
%{abidir}/libpdfdocument.dump
%{_libdir}/evince/4/backends/pdfdocument.evince-backend

%{_libdir}/evince/4/backends/libpsdocument.so
%{abidir}/libpsdocument.dump
%{_libdir}/evince/4/backends/psdocument.evince-backend

%{_libdir}/evince/4/backends/libtiffdocument.so
%{abidir}/libtiffdocument.dump
%{_libdir}/evince/4/backends/tiffdocument.evince-backend

%{_libdir}/evince/4/backends/libcomicsdocument.so
%{abidir}/libcomicsdocument.dump
%{_libdir}/evince/4/backends/comicsdocument.evince-backend

%{_libdir}/evince/4/backends/libxpsdocument.so
%{abidir}/libxpsdocument.dump
%{_libdir}/evince/4/backends/xpsdocument.evince-backend

%{_libdir}/girepository-1.0/EvinceDocument-3.0.typelib
%{_libdir}/girepository-1.0/EvinceView-3.0.typelib

%files devel
%{_datadir}/doc/libevview
%{_datadir}/doc/libevdocument
%dir %{_includedir}/evince
%{_includedir}/evince/3.0
%{_libdir}/libevview3.so
%{_libdir}/libevdocument3.so
%{_libdir}/pkgconfig/evince-view-3.0.pc
%{_libdir}/pkgconfig/evince-document-3.0.pc
%{_datadir}/gir-1.0/EvinceDocument-3.0.gir
%{_datadir}/gir-1.0/EvinceView-3.0.gir

%files dvi
%{_libdir}/evince/4/backends/libdvidocument.so
%{abidir}/libdvidocument.dump
%{_libdir}/evince/4/backends/dvidocument.evince-backend
%{_datadir}/metainfo/evince-dvidocument.metainfo.xml

%files djvu
%{_libdir}/evince/4/backends/libdjvudocument.so
%{abidir}/libdjvudocument.dump
%{_libdir}/evince/4/backends/djvudocument.evince-backend
%{_datadir}/metainfo/evince-djvudocument.metainfo.xml

%files thumbnailer
%{_bindir}/evince-thumbnailer
%{abidir}/evince-thumbnailer-option.list
%{_datadir}/thumbnailers/evince.thumbnailer
%{_mandir}/man1/evince-thumbnailer.1*

%files previewer
%{_bindir}/evince-previewer
%{abidir}/evince-previewer-option.list
%{_datadir}/applications/org.gnome.Evince-previewer.desktop
%{_mandir}/man1/evince-previewer.1*

%changelog
* Fri Mar 24 2023 Funda Wang <fundawang@yeah.net> - 44.1-1
- Import package for anolis 23
